@@ -45,13 +45,13 @@ ols_dsrvsp_plot <- function(model) {
 		ylab('Deleted Studentized Residual') +
 		ggtitle("Deleted Studentized Residual vs Predicted Values") +
 		geom_hline(yintercept = c(-2, 2), colour = 'red') +
-		geom_text(hjust = -0.2, nudge_x = 0.15, size = 3, family="serif", fontface="italic", colour="darkred") 
+		geom_text(hjust = -0.2, nudge_x = 0.15, size = 3, family="serif", fontface="italic", colour="darkred", na.rm = TRUE) 
 		annotate("text", x = Inf, y = Inf, hjust = 1.5, vjust = 2, 
       family="serif", fontface="italic", colour="darkred", 
       label = paste0('Threshold: abs(', 2, ')'))
 
 	suppressWarnings(print(p))
 	colnames(f) <- c("Observation", "Fitted Values", "Deleted Studentized Residual")
-	result <- list(outliers = f, threshold = 2)
+	result <- list(outliers = f, threshold = 2, plot = p)
 	invisible(result)
 }
\ No newline at end of file
