@@ -24,14 +24,18 @@
 #' @references Chatterjee, Samprit and Hadi, Ali. Regression Analysis by Example. 5th ed. N.p.: John Wiley & Sons, 2012. Print.
 #'
 #' @examples
+#' \dontrun{
 #' # stepwise backward regression
 #' model <- lm(y ~ ., data = surgical)
 #' ols_step_backward(model)
+#' }
 #'
+#' \dontrun{
 #' # stepwise backward regression plot
 #' model <- lm(y ~ ., data = surgical)
 #' k <- ols_step_backward(model)
 #' plot(k)
+#' }
 #'
 #' @export
 #'
@@ -227,6 +231,10 @@ plot.ols_step_backward <- function(x, model = NA, ...) {
 
     grid.arrange(p1, p2, p3, p4, p5, p6, ncol = 2, top = 'Stepwise Backward Regression')
 
+  result <- list(rsquare_plot = p1, adj_rsquare_plot = p2, mallows_cp_plot = p3,
+                aic_plot = p4, sbic_plot = p5, sbc_plot = p6)
+  invisible(result)
+
 }
 
 
