@@ -41,13 +41,13 @@ ols_srsd_chart <- function(model) {
 		geom_hline(yintercept = c(2, -2), colour = 'red') +
 		xlab('Observation') + ylab('Studentized Residuals') +
 		ggtitle('Standardized Residuals Chart') +
-		geom_text(hjust = -0.2, nudge_x = 0.15, size = 3, family="serif", fontface="italic", colour="darkred") +
+		geom_text(hjust = -0.2, nudge_x = 0.15, size = 3, family="serif", fontface="italic", colour="darkred", na.rm = TRUE) +
 		annotate("text", x = Inf, y = Inf, hjust = 1.5, vjust = 2, 
       family="serif", fontface="italic", colour="darkred", 
       label = paste0('Threshold: abs(', 2, ')'))
 
 	suppressWarnings(print(p))
 	colnames(f) <- c("Observation", "Studentized Residual")
-	result <- list(outliers = f, threshold = 2)
+	result <- list(outliers = f, threshold = 2, plot = p)
 	invisible(result)
 }
\ No newline at end of file
