@@ -2,25 +2,25 @@ context("pure_error_anova")
 
 test_that("output from pure_error_anova matches expected result", {
 
-	model <- lm(mpg ~ cyl, data = mtcars)
+	model <- lm(mpg ~ hp, data = mtcars)
 	k <- ols_pure_error_anova(model)
 	act <- k$lackoffit
-	exp <- 7.07
-	expect_equal(act, exp)
-	
+	exp <- 430.32
+	expect_equal(round(act, 2), exp)
+
 	act <- k$pure_error
-	exp <- 301.26
-	expect_equal(act, exp)
+	exp <- 17.36
+	expect_equal(round(act, 2), exp)
 
 	model <- lm(mpg ~ disp, data = mtcars)
 	k <- ols_pure_error_anova(model)
 	act <- k$lackoffit
 	exp <- 304.28
-	expect_equal(act, exp)
-	
+	expect_equal(round(act, 2), exp)
+
 	act <- k$pure_error
 	exp <- 12.88
-	expect_equal(act, exp)
+	expect_equal(round(act, 2), exp)
 
 })
 
@@ -35,6 +35,6 @@ test_that("pure_error_anova fails when model inherits other than 'lm'", {
 
 test_that("when object is not a simple linear regression, error is thrown", {
 	model <- lm(mpg ~ cyl + disp, data = mtcars)
-	expect_error(ols_pure_error_anova(model), 
+	expect_error(ols_pure_error_anova(model),
 		"Lack of fit F test is available only for simple linear regression.")
 })
